@@ -7,12 +7,12 @@ knitr::opts_chunk$set(
 ## -----------------------------------------------------------------------------
 pfile <- system.file("extdata", "point.shp", package = "vapour")
 library(vapour)
-vapour_read_attributes(pfile)
+vapour_read_fields(pfile)
 
 ## -----------------------------------------------------------------------------
 mvfile <- system.file("extdata", "tab", "list_locality_postcode_meander_valley.tab", package="vapour")
 
-dat <- as.data.frame(vapour_read_attributes(mvfile),  stringsAsFactors = FALSE)
+dat <- as.data.frame(vapour_read_fields(mvfile),  stringsAsFactors = FALSE)
 
 dim(dat)
 
@@ -34,7 +34,7 @@ str(vapour_read_geometry_text(cfile, textformat = "wkt")[1:2])
 
 ## -----------------------------------------------------------------------------
 library(dplyr)
-dat <- as.data.frame(vapour_read_attributes(cfile),  stringsAsFactors = FALSE) %>%
+dat <- as.data.frame(vapour_read_fields(cfile),  stringsAsFactors = FALSE) %>%
     dplyr::mutate(wkt = vapour_read_geometry_text(cfile, textformat = "wkt"))
 glimpse(dat)
 
@@ -81,10 +81,10 @@ mm[mm < -1e6] <- NA
 image(mm[,ncol(mm):1], asp = 2)
 
 ## -----------------------------------------------------------------------------
-vapour_read_attributes(mvfile, sql = "SELECT NAME, PLAN_REF FROM list_locality_postcode_meander_valley WHERE POSTCODE < 7291")
+vapour_read_fields(mvfile, sql = "SELECT NAME, PLAN_REF FROM list_locality_postcode_meander_valley WHERE POSTCODE < 7291")
 
 
-vapour_read_attributes(mvfile, sql = "SELECT NAME, PLAN_REF, FID FROM list_locality_postcode_meander_valley WHERE POSTCODE = 7306")
+vapour_read_fields(mvfile, sql = "SELECT NAME, PLAN_REF, FID FROM list_locality_postcode_meander_valley WHERE POSTCODE = 7306")
 
 
 ## -----------------------------------------------------------------------------
@@ -93,14 +93,14 @@ file0 <- "list_locality_postcode_meander_valley.tab"
 mvfile <- system.file("extdata/tab", file0, package="vapour")
 layer <- gsub(".tab$", "", basename(mvfile))
 ## get the number of features by FID (DISTINCT should be redundant here)
-vapour_read_attributes(mvfile, sql = sprintf("SELECT COUNT(DISTINCT FID) AS nfeatures FROM %s", layer))
+vapour_read_fields(mvfile, sql = sprintf("SELECT COUNT(DISTINCT FID) AS nfeatures FROM %s", layer))
 
 ## note how TAB is 1-based 
-vapour_read_attributes(mvfile, sql = sprintf("SELECT COUNT(*) AS n FROM %s WHERE FID < 2", layer))
+vapour_read_fields(mvfile, sql = sprintf("SELECT COUNT(*) AS n FROM %s WHERE FID < 2", layer))
 
 ## but SHP is 0-based
 shp <- system.file("extdata/point.shp", package="vapour")
-vapour_read_attributes(shp, sql = sprintf("SELECT COUNT(*) AS n FROM %s WHERE FID < 2", "point"))
+vapour_read_fields(shp, sql = sprintf("SELECT COUNT(*) AS n FROM %s WHERE FID < 2", "point"))
 
 ## ----GDAL-info----------------------------------------------------------------
 vapour_gdal_version()
